@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,37 @@ class TatClient(AbstractClient):
     _service = 'tat'
 
 
+    def CancelInvocation(self, request):
+        """取消一台或多台CVM实例执行的命令
+
+        * 如果命令还未下发到agent，任务状态处于处于PENDING、DELIVERING、DELIVER_DELAYED，取消后任务状态是CANCELLED
+        * 如果命令已下发到agent，任务状态处于RUNNING， 取消后任务状态是TERMINATED
+
+        :param request: Request instance for CancelInvocation.
+        :type request: :class:`tencentcloud.tat.v20201028.models.CancelInvocationRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.CancelInvocationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CancelInvocation", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CancelInvocationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateCommand(self, request):
         """此接口用于创建命令。
 
@@ -54,8 +85,37 @@ class TatClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateInvoker(self, request):
+        """此接口用于创建执行器。
+
+        :param request: Request instance for CreateInvoker.
+        :type request: :class:`tencentcloud.tat.v20201028.models.CreateInvokerRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.CreateInvokerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateInvoker", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateInvokerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteCommand(self, request):
         """此接口用于删除命令。
+        如果命令与执行器关联，则无法被删除。
 
         :param request: Request instance for DeleteCommand.
         :type request: :class:`tencentcloud.tat.v20201028.models.DeleteCommandRequest`
@@ -82,6 +142,34 @@ class TatClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteInvoker(self, request):
+        """此接口用于删除执行器。
+
+        :param request: Request instance for DeleteInvoker.
+        :type request: :class:`tencentcloud.tat.v20201028.models.DeleteInvokerRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.DeleteInvokerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteInvoker", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteInvokerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAutomationAgentStatus(self, request):
         """此接口用于查询自动化助手客户端的状态。
 
@@ -194,8 +282,65 @@ class TatClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeInvokerRecords(self, request):
+        """此接口用于查询执行器的执行记录。
+
+        :param request: Request instance for DescribeInvokerRecords.
+        :type request: :class:`tencentcloud.tat.v20201028.models.DescribeInvokerRecordsRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.DescribeInvokerRecordsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeInvokerRecords", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInvokerRecordsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeInvokers(self, request):
+        """此接口用于查询执行器信息。
+
+        :param request: Request instance for DescribeInvokers.
+        :type request: :class:`tencentcloud.tat.v20201028.models.DescribeInvokersRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.DescribeInvokersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeInvokers", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInvokersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRegions(self, request):
-        """此接口用于查询地域列表
+        """此接口用于查询 TAT 产品后台地域列表。
+        RegionState 为 AVAILABLE，代表该地域的 TAT 后台服务已经可用；未返回，代表该地域的 TAT 后台服务尚不可用。
 
         :param request: Request instance for DescribeRegions.
         :type request: :class:`tencentcloud.tat.v20201028.models.DescribeRegionsRequest`
@@ -222,6 +367,62 @@ class TatClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DisableInvoker(self, request):
+        """此接口用于停止执行器。
+
+        :param request: Request instance for DisableInvoker.
+        :type request: :class:`tencentcloud.tat.v20201028.models.DisableInvokerRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.DisableInvokerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DisableInvoker", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DisableInvokerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def EnableInvoker(self, request):
+        """此接口用于启用执行器。
+
+        :param request: Request instance for EnableInvoker.
+        :type request: :class:`tencentcloud.tat.v20201028.models.EnableInvokerRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.EnableInvokerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("EnableInvoker", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.EnableInvokerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InvokeCommand(self, request):
         """在指定的实例上触发命令，调用成功返回执行活动ID（inv-xxxxxxxx），每个执行活动内部有一个或多个执行任务（invt-xxxxxxxx），每个执行任务代表命令在一台 CVM 或一台 Lighthouse 上的执行记录。
 
@@ -284,6 +485,34 @@ class TatClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyInvoker(self, request):
+        """此接口用于修改执行器。
+
+        :param request: Request instance for ModifyInvoker.
+        :type request: :class:`tencentcloud.tat.v20201028.models.ModifyInvokerRequest`
+        :rtype: :class:`tencentcloud.tat.v20201028.models.ModifyInvokerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyInvoker", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyInvokerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def PreviewReplacedCommandContent(self, request):
         """此接口用于预览自定义参数替换后的命令内容。不会触发真实执行。
 
